==> camel-k-model-v1-6.2.0-sources.jar: io/fabric8/camelk/v1/IntegrationKitStatusFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface IntegrationKitStatusFluent<A extends IntegrationKitStatusFluent<A>> extends Fluent<A>{
  public A addToArtifacts(Integer index,Artifact item);
  public A setToArtifacts(Integer index,Artifact item);
  public A addToArtifacts(io.fabric8.camelk.v1.Artifact... items);
  public A addAllToArtifacts(Collection<Artifact> items);
  public A removeFromArtifacts(io.fabric8.camelk.v1.Artifact... items);
  public A removeAllFromArtifacts(Collection<Artifact> items);
  public A removeMatchingFromArtifacts(Predicate<ArtifactBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildArtifacts instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Artifact> getArtifacts();
  public List<Artifact> buildArtifacts();
  public Artifact buildArtifact(Integer index);
  public Artifact buildFirstArtifact();
  public Artifact buildLastArtifact();
  public Artifact buildMatchingArtifact(Predicate<ArtifactBuilder> predicate);
  public Boolean hasMatchingArtifact(Predicate<ArtifactBuilder> predicate);
  public A withArtifacts(List<Artifact> artifacts);
  public A withArtifacts(io.fabric8.camelk.v1.Artifact... artifacts);
  public Boolean hasArtifacts();
  public A addNewArtifact(String checksum,String id,String location,String target);
  public IntegrationKitStatusFluent.ArtifactsNested<A> addNewArtifact();
  public IntegrationKitStatusFluent.ArtifactsNested<A> addNewArtifactLike(Artifact item);
  public IntegrationKitStatusFluent.ArtifactsNested<A> setNewArtifactLike(Integer index,Artifact item);
  public IntegrationKitStatusFluent.ArtifactsNested<A> editArtifact(Integer index);
  public IntegrationKitStatusFluent.ArtifactsNested<A> editFirstArtifact();
  public IntegrationKitStatusFluent.ArtifactsNested<A> editLastArtifact();
  public IntegrationKitStatusFluent.ArtifactsNested<A> editMatchingArtifact(Predicate<ArtifactBuilder> predicate);
  public String getBaseImage();
  public A withBaseImage(String baseImage);
  public Boolean hasBaseImage();
  public A addToConditions(Integer index,IntegrationKitCondition item);
  public A setToConditions(Integer index,IntegrationKitCondition item);
  public A addToConditions(io.fabric8.camelk.v1.IntegrationKitCondition... items);
  public A addAllToConditions(Collection<IntegrationKitCondition> items);
  public A removeFromConditions(io.fabric8.camelk.v1.IntegrationKitCondition... items);
  public A removeAllFromConditions(Collection<IntegrationKitCondition> items);
  public A removeMatchingFromConditions(Predicate<IntegrationKitConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IntegrationKitCondition> getConditions();
  public List<IntegrationKitCondition> buildConditions();
  public IntegrationKitCondition buildCondition(Integer index);
  public IntegrationKitCondition buildFirstCondition();
  public IntegrationKitCondition buildLastCondition();
  public IntegrationKitCondition buildMatchingCondition(Predicate<IntegrationKitConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<IntegrationKitConditionBuilder> predicate);
  public A withConditions(List<IntegrationKitCondition> conditions);
  public A withConditions(io.fabric8.camelk.v1.IntegrationKitCondition... conditions);
  public Boolean hasConditions();
  public IntegrationKitStatusFluent.ConditionsNested<A> addNewCondition();
  public IntegrationKitStatusFluent.ConditionsNested<A> addNewConditionLike(IntegrationKitCondition item);
  public IntegrationKitStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,IntegrationKitCondition item);
  public IntegrationKitStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public IntegrationKitStatusFluent.ConditionsNested<A> editFirstCondition();
  public IntegrationKitStatusFluent.ConditionsNested<A> editLastCondition();
  public IntegrationKitStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<IntegrationKitConditionBuilder> predicate);
  public String getDigest();
  public A withDigest(String digest);
  public Boolean hasDigest();
  
  /**
   * This method has been deprecated, please use method buildFailure instead.
   * @return The buildable object.
   */
  @Deprecated
  public Failure getFailure();
  public Failure buildFailure();
  public A withFailure(Failure failure);
  public Boolean hasFailure();
  public IntegrationKitStatusFluent.FailureNested<A> withNewFailure();
  public IntegrationKitStatusFluent.FailureNested<A> withNewFailureLike(Failure item);
  public IntegrationKitStatusFluent.FailureNested<A> editFailure();
  public IntegrationKitStatusFluent.FailureNested<A> editOrNewFailure();
  public IntegrationKitStatusFluent.FailureNested<A> editOrNewFailureLike(Failure item);
  public String getImage();
  public A withImage(String image);
  public Boolean hasImage();
  public String getPhase();
  public A withPhase(String phase);
  public Boolean hasPhase();
  public String getPlatform();
  public A withPlatform(String platform);
  public Boolean hasPlatform();
  public String getRuntimeProvider();
  public A withRuntimeProvider(String runtimeProvider);
  public Boolean hasRuntimeProvider();
  public String getRuntimeVersion();
  public A withRuntimeVersion(String runtimeVersion);
  public Boolean hasRuntimeVersion();
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public interface ArtifactsNested<N> extends Nested<N>,ArtifactFluent<IntegrationKitStatusFluent.ArtifactsNested<N>>{
    public N and();
    public N endArtifact();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,IntegrationKitConditionFluent<IntegrationKitStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface FailureNested<N> extends Nested<N>,FailureFluent<IntegrationKitStatusFluent.FailureNested<N>>{
    public N and();
    public N endFailure();
    
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/IntegrationKitStatusFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;

 /**
  * Generated
  */
public interface IntegrationKitStatusFluent<A extends IntegrationKitStatusFluent<A>> extends Fluent<A>{
  public A addToArtifacts(int index,Artifact item);
  public A setToArtifacts(int index,Artifact item);
  public A addToArtifacts(io.fabric8.camelk.v1.Artifact... items);
  public A addAllToArtifacts(Collection<Artifact> items);
  public A removeFromArtifacts(io.fabric8.camelk.v1.Artifact... items);
  public A removeAllFromArtifacts(Collection<Artifact> items);
  public A removeMatchingFromArtifacts(Predicate<ArtifactBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildArtifacts instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Artifact> getArtifacts();
  public List<Artifact> buildArtifacts();
  public Artifact buildArtifact(int index);
  public Artifact buildFirstArtifact();
  public Artifact buildLastArtifact();
  public Artifact buildMatchingArtifact(Predicate<ArtifactBuilder> predicate);
  public Boolean hasMatchingArtifact(Predicate<ArtifactBuilder> predicate);
  public A withArtifacts(List<Artifact> artifacts);
  public A withArtifacts(io.fabric8.camelk.v1.Artifact... artifacts);
  public Boolean hasArtifacts();
  public A addNewArtifact(String checksum,String id,String location,String target);
  public IntegrationKitStatusFluent.ArtifactsNested<A> addNewArtifact();
  public IntegrationKitStatusFluent.ArtifactsNested<A> addNewArtifactLike(Artifact item);
  public IntegrationKitStatusFluent.ArtifactsNested<A> setNewArtifactLike(int index,Artifact item);
  public IntegrationKitStatusFluent.ArtifactsNested<A> editArtifact(int index);
  public IntegrationKitStatusFluent.ArtifactsNested<A> editFirstArtifact();
  public IntegrationKitStatusFluent.ArtifactsNested<A> editLastArtifact();
  public IntegrationKitStatusFluent.ArtifactsNested<A> editMatchingArtifact(Predicate<ArtifactBuilder> predicate);
  public String getBaseImage();
  public A withBaseImage(String baseImage);
  public Boolean hasBaseImage();
  public A addToConditions(int index,IntegrationKitCondition item);
  public A setToConditions(int index,IntegrationKitCondition item);
  public A addToConditions(io.fabric8.camelk.v1.IntegrationKitCondition... items);
  public A addAllToConditions(Collection<IntegrationKitCondition> items);
  public A removeFromConditions(io.fabric8.camelk.v1.IntegrationKitCondition... items);
  public A removeAllFromConditions(Collection<IntegrationKitCondition> items);
  public A removeMatchingFromConditions(Predicate<IntegrationKitConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IntegrationKitCondition> getConditions();
  public List<IntegrationKitCondition> buildConditions();
  public IntegrationKitCondition buildCondition(int index);
  public IntegrationKitCondition buildFirstCondition();
  public IntegrationKitCondition buildLastCondition();
  public IntegrationKitCondition buildMatchingCondition(Predicate<IntegrationKitConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<IntegrationKitConditionBuilder> predicate);
  public A withConditions(List<IntegrationKitCondition> conditions);
  public A withConditions(io.fabric8.camelk.v1.IntegrationKitCondition... conditions);
  public Boolean hasConditions();
  public IntegrationKitStatusFluent.ConditionsNested<A> addNewCondition();
  public IntegrationKitStatusFluent.ConditionsNested<A> addNewConditionLike(IntegrationKitCondition item);
  public IntegrationKitStatusFluent.ConditionsNested<A> setNewConditionLike(int index,IntegrationKitCondition item);
  public IntegrationKitStatusFluent.ConditionsNested<A> editCondition(int index);
  public IntegrationKitStatusFluent.ConditionsNested<A> editFirstCondition();
  public IntegrationKitStatusFluent.ConditionsNested<A> editLastCondition();
  public IntegrationKitStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<IntegrationKitConditionBuilder> predicate);
  public String getDigest();
  public A withDigest(String digest);
  public Boolean hasDigest();
  
  /**
   * This method has been deprecated, please use method buildFailure instead.
   * @return The buildable object.
   */
  @Deprecated
  public Failure getFailure();
  public Failure buildFailure();
  public A withFailure(Failure failure);
  public Boolean hasFailure();
  public IntegrationKitStatusFluent.FailureNested<A> withNewFailure();
  public IntegrationKitStatusFluent.FailureNested<A> withNewFailureLike(Failure item);
  public IntegrationKitStatusFluent.FailureNested<A> editFailure();
  public IntegrationKitStatusFluent.FailureNested<A> editOrNewFailure();
  public IntegrationKitStatusFluent.FailureNested<A> editOrNewFailureLike(Failure item);
  public String getImage();
  public A withImage(String image);
  public Boolean hasImage();
  public String getPhase();
  public A withPhase(String phase);
  public Boolean hasPhase();
  public String getPlatform();
  public A withPlatform(String platform);
  public Boolean hasPlatform();
  public String getRuntimeProvider();
  public A withRuntimeProvider(String runtimeProvider);
  public Boolean hasRuntimeProvider();
  public String getRuntimeVersion();
  public A withRuntimeVersion(String runtimeVersion);
  public Boolean hasRuntimeVersion();
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public interface ArtifactsNested<N> extends Nested<N>,ArtifactFluent<IntegrationKitStatusFluent.ArtifactsNested<N>>{
    public N and();
    public N endArtifact();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,IntegrationKitConditionFluent<IntegrationKitStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface FailureNested<N> extends Nested<N>,FailureFluent<IntegrationKitStatusFluent.FailureNested<N>>{
    public N and();
    public N endFailure();
    
  }
  
}
